"""toolstr is a suite of str processing tools, including formatting and drawing"""

from .charts import *
from .formats import *
from .outlines import *
from .spec import *
from .tables import *


__version__ = '0.8.2'
